@@ -22,10 +22,8 @@
 #include "../images/imageCoule.h"
 #include "../images/imageProb.h"
 #include "../images/imagePaths.h"
-#include "../images/imageDetection.h"
 #include "../images/imageConfluent.h"
 #include "../images/imageContours.h"
-#include "../images/imageDeNovo.h"
 #include "../parameters.h"
 
 bool copy_file(QString inputfile, QString outputfile) {
@@ -149,7 +147,7 @@ void MainWindow::moveGelImage(QMouseEvent * event) {
 		_before_x = event->x();
 		_before_y = event->y();
 
-		qDebug() << event->x() << " " << event->y() << endl;
+		qDebug() << event->x() << " " << event->y() << Qt::endl;
 		//scrollArea->widget()->move(event->x(), event->y());
 		scrollArea->horizontalScrollBar()->setSliderPosition(
 				scrollArea->horizontalScrollBar()->value() - dx);
@@ -245,16 +243,28 @@ void MainWindow::saveStepsDirectory() {
 }
 
 void MainWindow::print() {
-	Q_ASSERT(scrollArea->getGelImage()->pixmap());
+#if QT_VERSION < 0x060000
+	Q_ASSERT(!scrollArea->getGelImage()->pixmap(Qt::ReturnByValue).isNull());
+#else
+	Q_ASSERT(!scrollArea->getGelImage()->pixmap().isNull());
+#endif
 	QPrintDialog dialog(&printer, this);
 	if (dialog.exec()) {
 		QPainter painter(&printer);
 		QRect rect = painter.viewport();
-		QSize size = scrollArea->getGelImage()->pixmap()->size();
+#if QT_VERSION < 0x060000
+		QSize size = scrollArea->getGelImage()->pixmap(Qt::ReturnByValue).size();
 		size.scale(rect.size(), Qt::KeepAspectRatio);
 		painter.setViewport(rect.x(), rect.y(), size.width(), size.height());
-		painter.setWindow(scrollArea->getGelImage()->pixmap()->rect());
-		painter.drawPixmap(0, 0, *scrollArea->getGelImage()->pixmap());
+		painter.setWindow(scrollArea->getGelImage()->pixmap(Qt::ReturnByValue).rect());
+		painter.drawPixmap(0, 0, scrollArea->getGelImage()->pixmap(Qt::ReturnByValue));
+#else
+		QSize size = scrollArea->getGelImage()->pixmap().size();
+		size.scale(rect.size(), Qt::KeepAspectRatio);
+		painter.setViewport(rect.x(), rect.y(), size.width(), size.height());
+		painter.setWindow(scrollArea->getGelImage()->pixmap().rect());
+		painter.drawPixmap(0, 0, scrollArea->getGelImage()->pixmap());
+#endif
 	}
 }
 
@@ -403,7 +413,11 @@ void MainWindow::updateActions() {
 }
 
 void MainWindow::scaleImage(double factor) {
-	Q_ASSERT(scrollArea->getGelImage()->pixmap());
+#if QT_VERSION < 0x060000
+	Q_ASSERT(!scrollArea->getGelImage()->pixmap(Qt::ReturnByValue).isNull());
+#else
+	Q_ASSERT(!scrollArea->getGelImage()->pixmap().isNull());
+#endif
 	scrollArea->scaleImage(factor);
 
 	adjustScrollBar(scrollArea->horizontalScrollBar(), factor);
@@ -467,7 +481,7 @@ void MainWindow::runDetection(QString directory_to_save_all_steps) {
 		qDebug() << "MainWindow::runDetection _properties.isInverse() "
 				<< _properties.isInverse();
 
-		qDebug() << "Computing bead directions " << endl;
+		qDebug() << "Computing bead directions " << Qt::endl;
 		imageDirect directions;
 		const parameterDirect & parameter_direct =
 				beads_params.get_parameter_direction();
@@ -477,7 +491,7 @@ void MainWindow::runDetection(QString directory_to_save_all_steps) {
 			directions.save(directory_to_save_all_steps + "/DIRECTIONS.png");
 		}
 
-		qDebug() << "Beads are rolling" << endl;
+		qDebug() << "Beads are rolling" << Qt::endl;
 		imageCoule rolling;
 		rolling.compute_from_direct(directions);
 		if (!directory_to_save_all_steps.isEmpty()) {
@@ -485,7 +499,7 @@ void MainWindow::runDetection(QString directory_to_save_all_steps) {
 		}
 
 		//using confluent method :
-		qDebug() << "Computing bead paths" << endl;
+		qDebug() << "Computing bead paths" << Qt::endl;
 		imagePaths path;
 		path.compute_from_direct_and_coule(directions, rolling);
 
@@ -493,13 +507,13 @@ void MainWindow::runDetection(QString directory_to_save_all_steps) {
 			path.save(directory_to_save_all_steps + "/PATHS.png");
 		}
 
-		qDebug() << "Detecting merging paths and arrival positions" << endl;
+		qDebug() << "Detecting merging paths and arrival positions" << Qt::endl;
 		const parameterConfluent & parameter_confl =
 				beads_params.get_parameter_confluent();
-		qDebug() << " minflux : " << parameter_confl.get_minflux() << endl;
-		qDebug() << " minpath : " << parameter_confl.get_minpath() << endl;
-		qDebug() << " winconfl : " << parameter_confl.get_winconfl() << endl;
-		qDebug() << " minbeads : " << parameter_confl.get_minbeads() << endl;
+		qDebug() << " minflux : " << parameter_confl.get_minflux() << Qt::endl;
+		qDebug() << " minpath : " << parameter_confl.get_minpath() << Qt::endl;
+		qDebug() << " winconfl : " << parameter_confl.get_winconfl() << Qt::endl;
+		qDebug() << " minbeads : " << parameter_confl.get_minbeads() << Qt::endl;
 
 		imageConfluent confluent;
 		confluent.compute_from_direct_and_paths(directions, path, *p_gel_image,
@@ -508,12 +522,12 @@ void MainWindow::runDetection(QString directory_to_save_all_steps) {
 			confluent.save(directory_to_save_all_steps + "/SELECT.png");
 		}
 
-		qDebug() << "Computing probabilites of spot positions" << endl;
+		qDebug() << "Computing probabilites of spot positions" << Qt::endl;
 		const parameterProb & parameter_prob =
 				beads_params.get_parameter_prob();
-		qDebug() << " threshold : " << parameter_prob.get_threshold() << endl;
-		qDebug() << " sx : " << parameter_prob.get_sx() << endl;
-		qDebug() << " sy : " << parameter_prob.get_sy() << endl;
+		qDebug() << " threshold : " << parameter_prob.get_threshold() << Qt::endl;
+		qDebug() << " sx : " << parameter_prob.get_sx() << Qt::endl;
+		qDebug() << " sy : " << parameter_prob.get_sy() << Qt::endl;
 
 		imageProb dest_image_prob;
 
@@ -523,11 +537,11 @@ void MainWindow::runDetection(QString directory_to_save_all_steps) {
 					+ "/PROBABILITIES.png");
 		}
 
-		qDebug() << "Detecting spots" << endl;
+		qDebug() << "Detecting spots" << Qt::endl;
 		const parameterDetection & parameter_detection =
 				beads_params.get_parameter_detection();
 		qDebug() << " minproba : " << parameter_detection.get_minproba()
-				<< endl;
+				<< Qt::endl;
 
 		detection * p_the_detection_from_prob = new detection();
 		p_the_detection_from_prob->detect_from_prob(dest_image_prob,
@@ -535,7 +549,7 @@ void MainWindow::runDetection(QString directory_to_save_all_steps) {
 
 		//imageDetection img_detect(*p_the_detection_from_prob);
 
-		qDebug() << "Quantification" << endl;
+		qDebug() << "Quantification" << Qt::endl;
 		const parameterNumber & parameter_number =
 				beads_params.get_parameter_number();
 
